@@ -30,13 +30,15 @@ class GObjectIntrospection(Tarball, Meson):
         Project.__init__(
             self,
             "gobject-introspection",
-            archive_url="https://download.gnome.org/sources/gobject-introspection/1.74/gobject-introspection-1.74.0.tar.xz",
+            version="1.74.0",
+            repository="https://gitlab.gnome.org/GNOME/gobject-introspection",
+            archive_url="https://download.gnome.org/sources/gobject-introspection/{major}.{minor}/gobject-introspection-{version}.tar.xz",
             hash="347b3a719e68ba4c69ff2d57ee2689233ea8c07fc492205e573386779e42d653",
             dependencies=[
                 "ninja",
                 "meson",
                 "msys2",
-                "pkg-config",
+                "pkgconf",
                 "glib",
             ],
             # https://gitlab.gnome.org/GNOME/gobject-introspection/-/issues/427
@@ -58,6 +60,6 @@ class GObjectIntrospection(Tarball, Meson):
 
         Meson.build(
             self,
-            meson_params="-Dpython=%s\\python.exe -Dcairo_libname=cairo-gobject.dll"
+            meson_params="-Dpython=%s\\python.exe -Dcairo_libname=cairo-gobject-2.dll"
             % (py_dir,),
         )
